==> apt-cacher-ng_0.3.4.orig.tar.gz: apt-cacher-ng-0.3.4/source/meta.cc <==

#define LOCAL_DEBUG
#include "debug.h"

#include "meta.h"
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <cstdio>
#include <iostream>
using namespace MYSTD;

string sPathSep(SZPATHSEP);
string sPathSepUnix(SZPATHSEP);
const char *szPathSep=SZPATHSEP;
string sCRLF("\r\n");
string sLF("\n");

/*
int getUUID() {
    lfd=(lfd+1)%65536;
   //cerr << "UUID: " << lfd <<endl;
    return lfd;
}
*/
void set_nb(int fd) {
    int flags = fcntl(fd, F_GETFL);
    //ASSERT(flags != -1);
    flags |= O_NONBLOCK;
    flags = fcntl(fd, F_SETFL, flags);
}

void mkbasedir(const MYSTD::string & path) {
    unsigned int pos;
    for(pos=0;pos<path.size();pos=path.find("/", pos+1)) {
        if(pos>0)
            mkdir(path.substr(0,pos).c_str(), 00755);
    }
}
/*
inline tStrPos findHostStart(const MYSTD::string & sUri)
{
	tStrPos p=0, l=sUri.size();
	if (0==sUri.compare(0, 7, "http://"))
		p=7;
	while(p<l && sUri[p]=='/') p++;
	return p;
}

void trimProto(MYSTD::string & sUri)
{
	sUri.erase(findHostStart(sUri));
}
*/
/*

MYSTD::string sbasename(const char *in) {
	/
	const char *x=strrchr(in, (UINT)cPathSep);
	if(x[1]==0x0)
		*x=0x0;
	x=strrchr(in, (UINT)cPathSep);
	/
	
	MYSTD::string s(in);
	
	int l;
	for(l=int(s.length())-1;l>0&& s[l] == cPathSep;l--)
		s.resize(l);
	if(l>1&& s[l-1] == cPathSep)
		s.resize(l);
	l=s.find_last_of(cPathSep);
	if(l!=stmiss) s.erase(0,l+1);
	return s;
}

void find_base_name(const char *in, const char * &pos, UINT &len)
{
	int l=strlen(in);
	if(l==0)
	{
		pos=in;
		len=0;
		return;
	}
	
		const char *p, *r;
		
		for(p=in+l-1;*p==cPathSep;p--)
		{	
			if(p==in)
			{
				pos=in;
				len=1;
				return;
			}
		}
		for(r=p;r>=in && *p!=cPathSep;r--)
		{
			if(r==in)
			{
				pos=in;
				len=p-in+1;
			}
		}
	
}
*/

tStrVec::size_type Tokenize(const string & in, const char *sep, tStrVec & out, bool bAppend)
{
	if(!bAppend)
		out.clear();
	tStrVec::size_type nBefore(out.size());
	
	tStrPos pos=0, pos2=0, oob=in.length();
	while (pos<oob)
	{
		pos=in.find_first_not_of(sep, pos);
		if (pos==stmiss) // no more tokens
			goto tok_done;
		pos2=in.find_first_of(sep, pos);
		if (pos2==stmiss) // no more terminators, EOL
			pos2=oob;
		out.push_back(in.substr(pos, pos2-pos));
		pos=pos2+1;
	}
	tok_done:
	return out.size()-nBefore;
}


void StrSubst(string &contents, const string &from, const string &to)
{
	tStrPos pos;
	while (stmiss!=(pos=contents.find(from)))
	{
		contents.replace(pos, from.length(), to);
		pos+=to.length();
	}
}


void Join(MYSTD::string &out, const MYSTD::string & sep, const tStrVec & tokens)
{
	out.clear();
	if(tokens.empty())
		return;
	
	for(tStrVec::const_iterator it=tokens.begin(); it!=tokens.end(); it++)
		out+=(sep + *it);
			
}


bool _ParseLine(const string & sIn, string & sOutKey, string & sOutVal)
{
	// reuse the output string as buffer
	sOutVal=sIn;
	sOutKey.clear();
	trimFront(sOutVal);
	//cout << "parsing: "<<sOut<<endl;
	if(sOutVal.empty())
		return false;
	
	/*
	// comments or other crap, not for us
	if(stmiss!=sFilterString.find(sIn[0]))
		return false;
	*/
	
	string::size_type pos = sOutVal.find(":");
	if (pos==string::npos)
	{
		//cerr << "Bad configuration directive found, looking for: " << szKey << ", found: "<< sOut << endl;
		return false;
	}
	
	sOutKey = sOutVal.substr(0, pos);
	trimBack(sOutKey);
	
	sOutVal.erase(0, pos+1);
	trimFront(sOutVal);
	
	return true;
}


bool tHttpUrl::SetHttpUrl(string url)
{
	sPort.clear();
	sHost.clear();
	sPath.clear();
	
	trimBack(url);
	trimFront(url);
		
	if(url.empty())
		return false;
	
	tStrPos hStart(0), l=url.length(), hEndSuc(0), pStart(0), p;
	bool bCheckBrac=false;
	
	if(0==strncasecmp(url.c_str(), "http://", 7))
		hStart=7;
	/* checked below with others
	else if(url[0]=='/')
		hStart=1;
		*/
	else if(isalnum((UINT)url[0]))
		hStart=0;
	else if(url[0]=='[')
	{
		hStart=0;
		bCheckBrac=true; // must be closed
	}
	else if(stmiss!=url.find("://"))
		return false; // other protocol or weird stuff
	
	// kill leading slashes in any case
	while(hStart<l && url[hStart]=='/') hStart++;
	if(hStart>=l)
		return false;
	
	hEndSuc=url.find('/', hStart);
	if(stmiss==hEndSuc)
	{
		hEndSuc=l;
		goto extract_host_check_port;
	}
	pStart=hEndSuc;
	while(pStart<l && url[pStart]=='/') pStart++;
	pStart--;
	
	extract_host_check_port:
	if(pStart==0)
		sPath="/";
	else
		sPath=url.substr(pStart);

	if(url[hStart]=='_') // those are reserved
		return false;
	
	sHost=url.substr(hStart, hEndSuc-hStart);

	l=sHost.size();
	p=sHost.rfind(':');
	if(p==stmiss)
		goto strip_ipv6_junk;
	else if(p==l-1)
		return false; // this is crap, http:/asdf?
	else for(tStrPos r=p+1;r<l;r++)
		if(! isdigit(sHost[r]))
			return false;
	
	sPort=sHost.substr(p+1);
	sHost.erase(p);
	
	strip_ipv6_junk:
	
	if(sHost[0]=='[')
	{
		bCheckBrac=true;
		sHost.erase(0,1);
	}
	
	if(sHost[sHost.length()-1]==']')
		sHost.erase(sHost.length()-1);
	else if(bCheckBrac) // must have been present here
		return false;
	
	return true;
	
}

string tHttpUrl::ToString() const 
{ 
	return sPort.empty()? sHost+sPath : sHost+":"+sPort+sPath;
}
//tHttpUrl::tHttpUrl() : pMisc(NULL) {};

string ltos(long n)
{
	char buf[21];
	snprintf(buf, 21, "%ld", n);
	return buf;
}

/*
const MYSTD::string GetDateString() {
    char buf[26];
    struct tm tmp;
    const time_t cur=time(NULL);
    gmtime_r(&cur, &tmp);
    asctime_r(&tmp, buf);
    buf[24]=0x0;
//    cout << "generated date: " << buf<<endl;
    return buf;
    
}
*/

==> apt-cacher-ng_0.4.orig.tar.gz: apt-cacher-ng-0.4/source/meta.cc <==

#define LOCAL_DEBUG
#include "debug.h"

#include "meta.h"
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <cstdio>
#include <iostream>
using namespace MYSTD;

string sPathSep(SZPATHSEP);
string sPathSepUnix(SZPATHSEP);
const char *szPathSep=SZPATHSEP;
string sCRLF("\r\n");
string sLF("\n");

/*
int getUUID() {
    lfd=(lfd+1)%65536;
   //cerr << "UUID: " << lfd <<endl;
    return lfd;
}
*/
void set_nb(int fd) {
    int flags = fcntl(fd, F_GETFL);
    //ASSERT(flags != -1);
    flags |= O_NONBLOCK;
    flags = fcntl(fd, F_SETFL, flags);
}

void mkbasedir(const MYSTD::string & path) {
    unsigned int pos;
    for(pos=0;pos<path.size();pos=path.find("/", pos+1)) {
        if(pos>0)
            mkdir(path.substr(0,pos).c_str(), 00755);
    }
}
/*
inline tStrPos findHostStart(const MYSTD::string & sUri)
{
	tStrPos p=0, l=sUri.size();
	if (0==sUri.compare(0, 7, "http://"))
		p=7;
	while(p<l && sUri[p]=='/') p++;
	return p;
}

void trimProto(MYSTD::string & sUri)
{
	sUri.erase(findHostStart(sUri));
}
*/
/*

MYSTD::string sbasename(const char *in) {
	/
	const char *x=strrchr(in, (UINT)cPathSep);
	if(x[1]==0x0)
		*x=0x0;
	x=strrchr(in, (UINT)cPathSep);
	/
	
	MYSTD::string s(in);
	
	int l;
	for(l=int(s.length())-1;l>0&& s[l] == cPathSep;l--)
		s.resize(l);
	if(l>1&& s[l-1] == cPathSep)
		s.resize(l);
	l=s.find_last_of(cPathSep);
	if(l!=stmiss) s.erase(0,l+1);
	return s;
}

void find_base_name(const char *in, const char * &pos, UINT &len)
{
	int l=strlen(in);
	if(l==0)
	{
		pos=in;
		len=0;
		return;
	}
	
		const char *p, *r;
		
		for(p=in+l-1;*p==cPathSep;p--)
		{	
			if(p==in)
			{
				pos=in;
				len=1;
				return;
			}
		}
		for(r=p;r>=in && *p!=cPathSep;r--)
		{
			if(r==in)
			{
				pos=in;
				len=p-in+1;
			}
		}
	
}
*/

tStrVec::size_type Tokenize(const string & in, const char *sep, tStrVec & out, bool bAppend)
{
	if(!bAppend)
		out.clear();
	tStrVec::size_type nBefore(out.size());
	
	tStrPos pos=0, pos2=0, oob=in.length();
	while (pos<oob)
	{
		pos=in.find_first_not_of(sep, pos);
		if (pos==stmiss) // no more tokens
			goto tok_done;
		pos2=in.find_first_of(sep, pos);
		if (pos2==stmiss) // no more terminators, EOL
			pos2=oob;
		out.push_back(in.substr(pos, pos2-pos));
		pos=pos2+1;
	}
	tok_done:
	return out.size()-nBefore;
}


void StrSubst(string &contents, const string &from, const string &to)
{
	tStrPos pos;
	while (stmiss!=(pos=contents.find(from)))
	{
		contents.replace(pos, from.length(), to);
		pos+=to.length();
	}
}


void Join(MYSTD::string &out, const MYSTD::string & sep, const tStrVec & tokens)
{
	out.clear();
	if(tokens.empty())
		return;
	
	for(tStrVec::const_iterator it=tokens.begin(); it!=tokens.end(); it++)
		out+=(sep + *it);
			
}


bool _ParseLine(const string & sIn, string & sOutKey, string & sOutVal)
{
	// reuse the output string as buffer
	sOutVal=sIn;
	sOutKey.clear();
	trimFront(sOutVal);
	//cout << "parsing: "<<sOut<<endl;
	if(sOutVal.empty())
		return false;
	
	/*
	// comments or other crap, not for us
	if(stmiss!=sFilterString.find(sIn[0]))
		return false;
	*/
	
	string::size_type pos = sOutVal.find(":");
	if (pos==string::npos)
	{
		//cerr << "Bad configuration directive found, looking for: " << szKey << ", found: "<< sOut << endl;
		return false;
	}
	
	sOutKey = sOutVal.substr(0, pos);
	trimBack(sOutKey);
	
	sOutVal.erase(0, pos+1);
	trimFront(sOutVal);
	
	return true;
}


bool tHttpUrl::SetHttpUrl(string url)
{
	sPort.clear();
	sHost.clear();
	sPath.clear();
	
	trimBack(url);
	trimFront(url);
		
	if(url.empty())
		return false;
	
	tStrPos hStart(0), l=url.length(), hEndSuc(0), pStart(0), p;
	bool bCheckBrac=false;
	
	if(0==strncasecmp(url.c_str(), "http://", 7))
		hStart=7;
	/* checked below with others
	else if(url[0]=='/')
		hStart=1;
		*/
	else if(isalnum((UINT)url[0]))
		hStart=0;
	else if(url[0]=='[')
	{
		hStart=0;
		bCheckBrac=true; // must be closed
	}
	else if(stmiss!=url.find("://"))
		return false; // other protocol or weird stuff
	
	// kill leading slashes in any case
	while(hStart<l && url[hStart]=='/') hStart++;
	if(hStart>=l)
		return false;
	
	hEndSuc=url.find('/', hStart);
	if(stmiss==hEndSuc)
	{
		hEndSuc=l;
		goto extract_host_check_port;
	}
	pStart=hEndSuc;
	while(pStart<l && url[pStart]=='/') pStart++;
	pStart--;
	
	extract_host_check_port:
	if(pStart==0)
		sPath="/";
	else
		sPath=url.substr(pStart);

	if(url[hStart]=='_') // those are reserved
		return false;
	
	sHost=url.substr(hStart, hEndSuc-hStart);

	l=sHost.size();
	p=sHost.rfind(':');
	if(p==stmiss)
		goto strip_ipv6_junk;
	else if(p==l-1)
		return false; // this is crap, http:/asdf?
	else for(tStrPos r=p+1;r<l;r++)
		if(! isdigit(sHost[r]))
			return false;
	
	sPort=sHost.substr(p+1);
	sHost.erase(p);
	
	strip_ipv6_junk:
	
	if(sHost[0]=='[')
	{
		bCheckBrac=true;
		sHost.erase(0,1);
	}
	
	if(sHost[sHost.length()-1]==']')
		sHost.erase(sHost.length()-1);
	else if(bCheckBrac) // must have been present here
		return false;
	
	return true;
	
}

string tHttpUrl::ToURI() const 
{ 
	return string("http://") + (sPort.empty()? (sHost+sPath) : (sHost+":"+sPort+sPath));
}
//tHttpUrl::tHttpUrl() : pMisc(NULL) {};

string ltos(long n)
{
	char buf[21];
	snprintf(buf, 21, "%ld", n);
	return buf;
}

/*
const MYSTD::string GetDateString() {
    char buf[26];
    struct tm tmp;
    const time_t cur=time(NULL);
    gmtime_r(&cur, &tmp);
    asctime_r(&tmp, buf);
    buf[24]=0x0;
//    cout << "generated date: " << buf<<endl;
    return buf;
    
}
*/
